import { CloudFormationCustomResourceEvent, CloudFormationCustomResourceCreateEvent, CloudFormationCustomResourceUpdateEvent, CloudFormationCustomResourceDeleteEvent, Context } from 'aws-lambda';
import { LogFactory, Logger } from './log-factory';
export interface ResourceHandlerReturn {
    physicalResourceId: string;
    responseData: {
        [Key: string]: any;
    };
}
export interface ResourceHandler {
    onCreate(event: CloudFormationCustomResourceCreateEvent, context: Context, logger: Logger): Promise<ResourceHandlerReturn>;
    onUpdate(event: CloudFormationCustomResourceUpdateEvent, context: Context, logger: Logger): Promise<ResourceHandlerReturn>;
    onDelete(event: CloudFormationCustomResourceDeleteEvent, context: Context, logger: Logger): Promise<void>;
}
export interface ResourceHandlerFactory {
    (logger?: Logger): ResourceHandler | Promise<ResourceHandler>;
}
export declare const customResourceHelper: (resourceHandlerFactory: ResourceHandlerFactory, logFactory?: LogFactory | undefined) => (event: CloudFormationCustomResourceEvent, context: Context) => Promise<void | {}>;
